@@ -1,7 +1,8 @@
+import pickle
+
 from pandas import DataFrame
 
 import numpy
-import pickle
 import pkg_resources
 
 from .metadata import __copyright__, __license__, __version__
@@ -119,6 +120,9 @@ class Evaluator(JavaObject):
 		except Exception as e:
 			raise self.backend.toJavaError(e)
 		results = self.backend.loads(results)
+		if hasattr(self, "dropColumns"):
+			for dropColumn in self.dropColumns:
+				del results[dropColumn]
 		return results
 
 	def evaluateAll(self, arguments_df, nan_as_missing = True):
@@ -130,7 +134,18 @@ class Evaluator(JavaObject):
 		except Exception as e:
 			raise self.backend.toJavaError(e)
 		result_records = self.backend.loads(result_records)
-		return DataFrame.from_records(result_records)
+		results_df = DataFrame.from_records(result_records)
+		if hasattr(self, "dropColumns"):
+			for dropColumn in self.dropColumns:
+				results_df.drop(str(dropColumn), axis = 1, inplace = True)
+		return results_df
+
+	def suppressResultFields(self, resultFields):
+		if resultFields:
+			self.dropColumns = [resultField.getName() for resultField in resultFields]
+		else:
+			if hasattr(self, "dropColumns"):
+				del self.dropColumns
 
 class BaseModelEvaluatorBuilder(JavaObject):
 
@@ -216,4 +231,4 @@ def _classpath(user_classpath):
 	return _package_classpath() + user_classpath
 
 def _package_classpath():
-	return _package_data_jars("jpmml_evaluator.resources") + _package_data_jars("jpmml_evaluator.dependencies")
\ No newline at end of file
+	return _package_data_jars("jpmml_evaluator.resources") + _package_data_jars("jpmml_evaluator.dependencies")
