@@ -1,9 +1,9 @@
-from jpmml_evaluator import _classpath, JavaBackend, JavaError
-
 import jnius_config
 
+from jpmml_evaluator import _classpath, JavaBackend, JavaError
+
 def jnius_configure_classpath(user_classpath = []):
-	jnius_config.set_classpath(*_classpath(user_classpath))
+	jnius_config.set_classpath(*_classpath(user_classpath = user_classpath))
 
 class PyJNIusBackend(JavaBackend):
 
@@ -33,4 +33,4 @@ class PyJNIusBackend(JavaBackend):
 		from jnius import JavaException
 		if isinstance(e, JavaException):
 			return JavaError(self, e.classname, e.innermessage, e.stacktrace)
-		return e
\ No newline at end of file
+		return e
